@@ -1,13 +1,14 @@
 # -*- perl -*-
 
 #
+# $Id: Makefile.pm,v 1.9 2002/10/18 16:09:25 eserte Exp $
 # Author: Slaven Rezic
 #
-# Copyright (C) 2002,2003,2005,2008,2013 Slaven Rezic. All rights reserved.
+# Copyright (C) 2002 Slaven Rezic. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 #
-# Mail: srezic@cpan.org
+# Mail: slaven.rezic@berlin.de
 # WWW:  http://www.rezic.de/eserte/
 #
 
@@ -17,83 +18,64 @@ use Make;
 use strict;
 
 use vars qw($VERSION $V);
-$VERSION = '1.16_50';
+$VERSION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
 
 $V = 0 unless defined $V;
 
 sub new {
-    my($pkg, $g, $make, $prefix, %args) = @_;
+    my($pkg, $g, $make, $prefix) = @_;
     $g = GraphViz->new unless $g;
     if (!$make) {
 	$make = Make->new;
     } elsif (!UNIVERSAL::isa($make, "Make")) {
 	$make = Make->new(Makefile => $make);
     }
-
-    my @allowed_args = qw(reversed);
-    my %allowed_args = map {($_,undef)} @allowed_args;
-    while(my($k,$v) = each %args) {
-	die "Unrecognized argument $k, known arguments are @allowed_args"
-	    if !exists $allowed_args{$k};
-    }
-
     my $self = { GraphViz => $g,
 		 Make     => $make,
 		 Prefix   => ($prefix||""),
-		 %args
 	       };
     bless $self, $pkg;
 }
 
-sub GraphViz { shift->{GraphViz} }
-sub Make     { shift->{Make}     }
-
 sub generate {
     my($self, $target) = @_;
     $target = "all" if !defined $target;
     my $seen = {};
-    my $expanded_target = $self->{Make}->subsvars($target);
-    $self->_generate($target, $expanded_target, $seen);
+    $self->_generate($target, $seen);
 }
 
 sub _generate {
-    my($self, $target, $expanded_target, $seen) = @_;
-    return if $seen->{$expanded_target};
-    $seen->{$expanded_target}++;
+    my($self, $target, $seen) = @_;
+    return if $seen->{$target};
     my $make_target = $self->{Make}->Target($target);
     if (!$make_target) {
 	warn "Can't get make target for $target\n" if $V;
+	$seen->{$target}++;
 	return;
     }
     my @depends = $self->_all_depends($self->{Make}, $make_target);
     if (!@depends) {
+	$seen->{$target}++;
 	warn "No depends for target $target\n" if $V;
 	return;
     }
     my $g = $self->{GraphViz};
     my $prefix = $self->{Prefix};
-    $g->add_node($prefix.$expanded_target);
-    foreach my $dep_def (@depends) {
-	my $expanded_dep = $dep_def->{expanded};
-	$g->add_node($prefix.$expanded_dep) unless $seen->{$expanded_dep};
-	if ($self->{reversed}) {
-	    $g->add_edge($prefix.$expanded_dep, $prefix.$expanded_target);
-	    warn "$prefix$expanded_dep => $prefix$expanded_target\n" if $V >= 2;
-	} else {
-	    $g->add_edge($prefix.$expanded_target, $prefix.$expanded_dep);
-	    warn "$prefix$expanded_target => $prefix$expanded_dep\n" if $V >= 2;
-	}
+    $g->add_node("$prefix$target");
+    foreach my $dep (@depends) {
+	$g->add_node("$prefix$dep") unless $seen->{$dep};
+	$g->add_edge("$prefix$target", "$prefix$dep");
+#warn "$prefix$target => $prefix$dep\n";
     }
     $seen->{$target}++;
-    foreach my $dep_def (@depends) {
-	my($expanded_dep, $unexpanded_dep) = @{$dep_def}{qw(expanded unexpanded)};
-	$self->_generate($unexpanded_dep, $expanded_dep, $seen);
+    foreach my $dep (@depends) {
+	$self->_generate($dep, $seen);
     }
 }
 
 sub guess_external_makes {
     my($self, $make_rule, $cmd) = @_;
-    if (defined $cmd && $cmd =~ /\bcd\s+(\w+)\s*(?:;|&&)\s*make\s*(.*)/) {
+    if ($cmd =~ /\bcd\s+(\w+)\s*(?:;|&&)\s*make\s*(.*)/) {
 	my($dir, $makeargs) = ($1, $2);
 	my $makefile;
 	my $rule;
@@ -129,23 +111,18 @@ sub _all_depends {
     my($self, $make, $make_target) = @_;
     my @depends;
     if ($make_target->colon) {
-	push @depends, $make_target->colon->depend;
-#	push @depends, $make_target->colon->exp_depend;
+#	push @depends, $make_target->colon->depend;
+	push @depends, $make_target->colon->exp_depend;
 	$self->guess_external_makes($make_target, $make_target->colon->exp_command);
     } elsif ($make_target->dcolon) {
 	foreach my $rule ($make_target->dcolon) {
-	    push @depends, $rule->depend;
-	    #push @depends, $rule->exp_depend;
+	    #push @depends, $rule->depend;
+	    push @depends, $rule->exp_depend;
 	    $self->guess_external_makes($rule, $rule->exp_command);
 	}
     }
-    map
-	{ +{ unexpanded => $_,
-	     expanded   => $make->subsvars($_),
-	   }
-      } @depends;
-    #    map { split(/\s+/,$make->subsvars($_)) } @depends;
-    #    @depends;
+#    map { split(/\s+/,$make->subsvars($_)) } @depends;
+    @depends;
 }
 
 {
@@ -179,7 +156,6 @@ package
       {
 #XXX $@ not defined?
 #XXX       die "$var not defined in '$_'" unless (length($var) > 1); 
-warn "$var not defined in '$_'" unless (length($var) > 1); 
        $value = '';
       }
      if (defined $op)
@@ -255,109 +231,3 @@ warn "$var not defined in '$_'" unless (length($var) > 1);
 }
 
 1;
-
-
-__END__
-
-=head1 NAME
-
-GraphViz::Makefile - Create Makefile graphs using GraphViz
-
-=head1 SYNOPSIS
-
-Output to a .png file:
-
-    use GraphViz::Makefile;
-    my $gm = GraphViz::Makefile->new(undef, "Makefile");
-    $gm->generate("all"); # or another makefile target
-    open my $ofh, ">", "makefile.png" or die $!;
-    binmode $ofh;
-    print $ofh $gm->GraphViz->as_png;
-
-Output to a .ps file:
-
-    use GraphViz::Makefile;
-    my $gm = GraphViz::Makefile->new(undef, "Makefile");
-    $gm->generate("all"); # or another makefile target
-    open my $ofh, ">", "makefile.ps" or die $!;
-    binmode $ofh;
-    print $ofh $gm->GraphViz->as_ps;
-
-=head1 DESCRIPTION
-
-B<GraphViz::Makefile> uses the L<GraphViz> and L<Make> modules to
-visualize Makefile dependencies.
-
-=head2 METHODS
-
-=over
-
-=item new($graphviz, $makefile, $prefix, %args)
-
-Create a C<GraphViz::Makefile> object. The first argument should be a
-C<GraphViz> object or C<undef>. In the latter case, a new C<GraphViz>
-object is created by the constructor. The second argument should be a
-C<Make> object, the filename of a Makefile, or C<undef>. In the latter
-case, the default Makefile is used. The third argument C<$prefix> is
-optional and can be used to prepend a prefix to all rule names in the
-graph output.
-
-Further arguments (specified as key-value pairs):
-
-=over
-
-=item reversed => 1
-
-Point arrows in the direction of dependencies. If not set, then the
-arrows point in the direction of "build flow".
-
-=back
-
-=item generate($rule)
-
-Generate the graph, beginning at the named Makefile rule. If C<$rule>
-is not given, C<all> is used instead.
-
-=item GraphViz
-
-Return a reference to the C<GraphViz> object. This object can be used
-for the output methods.
-
-=item Make
-
-Return a reference to the C<Make> object.
- 
-=back
-
-=head2 MEMBERS
-
-For backward compatibility, the following members in the hash-based
-C<GraphViz::Makefile> object may be used instead of the methods:
-
-=over
-
-=item * GraphViz
-
-=item * Make
-
-=back
-
-=head2 ALTERNATIVES
-
-There's another module doing the same thing: L<Makefile::GraphViz>.
-
-=head1 AUTHOR
-
-Slaven Rezic <srezic@cpan.org>
-
-=head1 COPYRIGHT
-
-Copyright (c) 2002,2003,2005,2008,2013 Slaven Rezic. All rights reserved.
-This module is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
-=head1 SEE ALSO
-
-L<GraphViz>, L<Make>, L<make(1)>, L<tkgvizmakefile>.
-
-=cut
